Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(405)

Unified Diff: chrome/browser/ui/cocoa/styled_text_field_cell.h

Issue 15553008: Instant Extended: Reduce clipping in omnibox (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Created 7 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/ui/cocoa/styled_text_field_cell.h
diff --git a/chrome/browser/ui/cocoa/styled_text_field_cell.h b/chrome/browser/ui/cocoa/styled_text_field_cell.h
index a1bf3bd5136a38c8cc9d4bf02d83c50c551faaf5..d0d0e4904ed9f0d6084bae40adc0aa78050c1477 100644
--- a/chrome/browser/ui/cocoa/styled_text_field_cell.h
+++ b/chrome/browser/ui/cocoa/styled_text_field_cell.h
@@ -10,7 +10,7 @@
#import "chrome/browser/ui/cocoa/rect_path_utils.h"
// StyledTextFieldCell customizes the look of the standard Cocoa text field.
-// The border and focus ring are modified, as is the font baseline. Subclasses
+// The border and focus ring are modified, as is the drawing rect. Subclasses
// can override |drawInteriorWithFrame:inView:| to provide custom drawing for
// decorations, but they must make sure to call the superclass' implementation
// with a modified frame after performing any custom drawing.
@@ -35,9 +35,13 @@
// Subclasses should override this method if they add any decorations.
- (NSRect)textFrameForFrame:(NSRect)cellFrame;
-// Baseline adjust for the text in this cell. Defaults to 0. Subclasses should
-// override as needed.
-- (CGFloat)baselineAdjust;
+// Offset from the top of the cell frame to the text frame. Defaults to 0.
+// Subclasses should
+- (CGFloat)topTextFrameOffset;
+
+// Offset from the bottom of the cell frame to the text frame. Defaults to 0.
+// Subclasses should
+- (CGFloat)bottomTextFrameOffset;
// Radius of the corners of the field. Defaults to square corners (0.0).
- (CGFloat)cornerRadius;

Powered by Google App Engine
This is Rietveld 408576698